@@ -16,6 +16,8 @@ void AccountsPlugin::registerTypes(const char *uri)
     QResource::registerResource(QStringLiteral("assets:/android_rcc_bundle.rcc"));
     #endif
     
+    Q_ASSERT(QLatin1String(uri) == QLatin1String("org.mauikit.accounts"));
+
     qmlRegisterSingletonType<MauiAccounts>(uri, 1, 0, "Accounts", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
         Q_UNUSED(scriptEngine)
         auto accounts = MauiAccounts::instance();
@@ -23,11 +25,9 @@ void AccountsPlugin::registerTypes(const char *uri)
         return accounts;
     });
     
-    
-    
-    qmlRegisterType(resolveFileUrl(QStringLiteral("AccountsMenuItem.qml")), uri, 1, 0, "AccountsMenuItem"); 
-    qmlRegisterType(resolveFileUrl(QStringLiteral("AccountsDialog.qml")), uri, 1, 0, "AccountsDialog"); 
-    qmlRegisterType(resolveFileUrl(QStringLiteral("CredentialsDialog.qml")), uri, 1, 0, "CredentialsDialog"); 
+    qmlRegisterType(componentUrl(QStringLiteral("AccountsMenuItem.qml")), uri, 1, 0, "AccountsMenuItem");
+    qmlRegisterType(componentUrl(QStringLiteral("AccountsDialog.qml")), uri, 1, 0, "AccountsDialog");
+    qmlRegisterType(componentUrl(QStringLiteral("CredentialsDialog.qml")), uri, 1, 0, "CredentialsDialog");
 }
 
 void AccountsPlugin::initializeEngine(QQmlEngine *engine, const char *uri)
@@ -36,3 +36,8 @@ void AccountsPlugin::initializeEngine(QQmlEngine *engine, const char *uri)
     Q_UNUSED(engine);
     
 }
+
+QUrl AccountsPlugin::componentUrl(const QString &fileName) const
+{
+    return QUrl(resolveFileUrl(fileName));
+}
